==> uxkit-0.0.2.tgz: package/built/UXKit/Control.js <==
/// <reference path="../../typings/tsd.d.ts"/>
import * as React from "react";
import { GestureRecognizerState, ControlEvents, ControlState } from "./Enum";
import { View } from "./View";
import { TapGestureRecognizer } from "./GestureRecognizer";
/**
 * Control
 */
export class Control extends View {
    constructor(props) {
        super(props);
        // private 
        this.inside = true;
        this.last = new Date();
        this.canceled = false;
        this.highlightedDelayed = false;
        this.state = {
            highlighted: false
        };
        this.tapGesture = new TapGestureRecognizer(this.handler.bind(this));
    }
    content() {
        return this.props.children;
    }
    controlState() {
        if (this.props.enabled === false) {
            return ControlState.Disabled;
        }
        else if (this.state.highlighted === true) {
            return ControlState.Highlighted;
        }
        else if (this.props.selected === true) {
            return ControlState.Selected;
        }
        else {
            return ControlState.Normal;
        }
    }
    eventHandler(event, sender, touchValues) {
        this.props.handler(event, sender);
    }
    view() {
        return (React.createElement(View, {ref: "view", gestureRecognizers: [this.tapGesture], backTouchingArea: this.props.backTouchingArea, style: this.style()}, this.content()));
    }
    style() {
        let style = {};
        return {
            flex: 1,
            justifyContent: function () {
                if (this.props.contentVerticalAlignment == "top") {
                    return "flex-start";
                }
                else if (this.props.contentVerticalAlignment == "bottom") {
                    return "flex-end";
                }
                else {
                    return "center";
                }
            }.bind(this)(),
            alignItems: function () {
                if (this.props.contentHorizontalAlignment == "left") {
                    return "flex-start";
                }
                else if (this.props.contentHorizontalAlignment == "right") {
                    return "flex-end";
                }
                else {
                    return "center";
                }
            }.bind(this)(),
        };
    }
    handler(state, values) {
        if (!this.props.enabled) {
            return;
        }
        if (state == GestureRecognizerState.Began) {
            this.canceled = false;
            let fingerID = values.touchIDs[values.touchIDs.length - 1];
            if (typeof fingerID === "number" || typeof fingerID === "string") {
                let touch = values.touches[fingerID];
                this.eventHandler(ControlEvents.TouchDown, this, touch);
                this.highlightedDelayed = false;
                if (this.props.delaysContentTouches === true) {
                    this.highlightedDelayed = true;
                    setTimeout(() => {
                        if (!this.canceled) {
                            this.highlightedDelayed = false;
                            this.setState({
                                highlighted: true
                            });
                        }
                    }, 50);
                }
                if (!this.highlightedDelayed) {
                    this.setState({
                        highlighted: true
                    });
                }
                var currentTime = new Date().getTime();
                var lastTime = this.last.getTime();
                if (currentTime - lastTime < 250) {
                    this.eventHandler(ControlEvents.TouchDownRepeat, this, touch);
                }
            }
        }
        else if (state == GestureRecognizerState.Changed) {
            let fingerID = values.touchIDs[values.touchIDs.length - 1];
            if (typeof fingerID === "number" || typeof fingerID === "string") {
                let touch = values.touches[fingerID];
                if (touch !== undefined) {
                    if (touch.startX + touch.offsetX > -this.props.moveAllow && touch.startY + touch.offsetY > -this.props.moveAllow &&
                        touch.startX + touch.offsetX < this.refs["view"].bounds.width + this.props.moveAllow &&
                        touch.startY + touch.offsetY < this.refs["view"].bounds.height + this.props.moveAllow) {
                        this.eventHandler(ControlEvents.TouchDragInside, this, touch);
                        // console.log("TouchDragInside")
                        if (!this.inside) {
                            this.setState({
                                highlighted: true
                            });
                            this.eventHandler(ControlEvents.TouchDragEnter, this, touch);
                            this.inside = true;
                        }
                    }
                    else {
                        this.eventHandler(ControlEvents.TouchDragOutside, this, touch);
                        // console.log("TouchDragOutside")
                        if (this.inside) {
                            this.setState({
                                highlighted: false
                            });
                            this.eventHandler(ControlEvents.TouchDragExit, this, touch);
                            this.inside = false;
                        }
                    }
                }
            }
        }
        else if (state == GestureRecognizerState.Ended) {
            this.canceled = true;
            this.setState({
                highlighted: false
            });
            let fingerID = values.touchIDs[values.touchIDs.length - 1];
            if (typeof fingerID === "number" || typeof fingerID === "string") {
                let touch = values.touches[fingerID];
                if (touch !== undefined && !this.highlightedDelayed) {
                    // console.log(touch);
                    // console.log(this.refs["view"].bounds);
                    if (touch.startX + touch.offsetX > -this.props.moveAllow && touch.startY + touch.offsetY > -this.props.moveAllow &&
                        touch.startX + touch.offsetX < this.refs["view"].bounds.width + this.props.moveAllow &&
                        touch.startY + touch.offsetY < this.refs["view"].bounds.height + this.props.moveAllow) {
                        this.eventHandler(ControlEvents.TouchUpInside, this, touch);
                    }
                    else {
                        this.eventHandler(ControlEvents.TouchUpOutside, this, touch);
                    }
                }
                else if (touch !== undefined && this.highlightedDelayed) {
                    // Light Press (轻触)
                    if (touch.offsetX > -this.props.moveAllow && touch.offsetY > -this.props.moveAllow &&
                        touch.offsetX < this.props.moveAllow &&
                        touch.offsetY < this.props.moveAllow) {
                        this.eventHandler(ControlEvents.TouchUpInside, this, touch);
                    }
                }
                else {
                    this.eventHandler(ControlEvents.TouchCancel, this, touch);
                }
            }
            else {
                this.eventHandler(ControlEvents.TouchCancel, this, undefined);
            }
        }
        else if (state == GestureRecognizerState.Cancelled) {
            this.canceled = true;
            this.setState({
                highlighted: false
            });
            let fingerID = values.touchIDs[values.touchIDs.length - 1];
            if (typeof fingerID === "number" || typeof fingerID === "string") {
                let touch = values.touches[fingerID];
                this.eventHandler(ControlEvents.TouchCancel, this, touch);
            }
        }
    }
}
Control.defaultProps = Object.assign({}, View.defaultProps, {
    enabled: true,
    selected: false,
    contentHorizontalAlignment: "center",
    contentVerticalAlignment: "center",
    moveAllow: 44.0,
    delaysContentTouches: false,
    handler: () => { },
});

==> uxkit-0.0.3.tgz: package/built/UXKit/Control.js <==
/// <reference path="../../typings/tsd.d.ts"/>
import * as React from "react";
import { GestureRecognizerState, ControlEvents, ControlState } from "./Enum";
import { View } from "./View";
import { TapGestureRecognizer } from "./GestureRecognizer";
/**
 * Control
 */
export class Control extends View {
    constructor(props) {
        super(props);
        // private 
        this.inside = true;
        this.last = new Date();
        this.canceled = false;
        this.highlightedDelayed = false;
        this.state = {
            highlighted: false
        };
        this.tapGesture = new TapGestureRecognizer(this.handler.bind(this));
    }
    content() {
        return this.props.children;
    }
    controlState() {
        if (this.props.enabled === false) {
            return ControlState.Disabled;
        }
        else if (this.state.highlighted === true) {
            return ControlState.Highlighted;
        }
        else if (this.props.selected === true) {
            return ControlState.Selected;
        }
        else {
            return ControlState.Normal;
        }
    }
    eventHandler(event, sender, touchValues) {
        this.props.handler(event, sender);
    }
    view() {
        return (React.createElement(View, {ref: "view", userInteractionEnabled: true, gestureRecognizers: [this.tapGesture], backTouchingArea: this.props.backTouchingArea, style: this.style()}, this.content()));
    }
    style() {
        let style = {};
        return {
            flex: 1,
            justifyContent: function () {
                if (this.props.contentVerticalAlignment == "top") {
                    return "flex-start";
                }
                else if (this.props.contentVerticalAlignment == "bottom") {
                    return "flex-end";
                }
                else {
                    return "center";
                }
            }.bind(this)(),
            alignItems: function () {
                if (this.props.contentHorizontalAlignment == "left") {
                    return "flex-start";
                }
                else if (this.props.contentHorizontalAlignment == "right") {
                    return "flex-end";
                }
                else {
                    return "center";
                }
            }.bind(this)(),
        };
    }
    handler(state, values) {
        if (!this.props.enabled) {
            return;
        }
        if (state == GestureRecognizerState.Began) {
            this.canceled = false;
            let fingerID = values.touchIDs[values.touchIDs.length - 1];
            if (typeof fingerID === "number" || typeof fingerID === "string") {
                let touch = values.touches[fingerID];
                this.eventHandler(ControlEvents.TouchDown, this, touch);
                this.highlightedDelayed = false;
                if (this.props.delaysContentTouches === true) {
                    this.highlightedDelayed = true;
                    setTimeout(() => {
                        if (!this.canceled) {
                            this.highlightedDelayed = false;
                            this.setState({
                                highlighted: true
                            });
                        }
                    }, 50);
                }
                if (!this.highlightedDelayed) {
                    this.setState({
                        highlighted: true
                    });
                }
                var currentTime = new Date().getTime();
                var lastTime = this.last.getTime();
                if (currentTime - lastTime < 250) {
                    this.eventHandler(ControlEvents.TouchDownRepeat, this, touch);
                }
            }
        }
        else if (state == GestureRecognizerState.Changed) {
            let fingerID = values.touchIDs[values.touchIDs.length - 1];
            if (typeof fingerID === "number" || typeof fingerID === "string") {
                let touch = values.touches[fingerID];
                if (touch !== undefined) {
                    if (touch.startX + touch.offsetX > -this.props.moveAllow && touch.startY + touch.offsetY > -this.props.moveAllow &&
                        touch.startX + touch.offsetX < this.refs["view"].bounds.width + this.props.moveAllow &&
                        touch.startY + touch.offsetY < this.refs["view"].bounds.height + this.props.moveAllow) {
                        this.eventHandler(ControlEvents.TouchDragInside, this, touch);
                        // console.log("TouchDragInside")
                        if (!this.inside) {
                            this.setState({
                                highlighted: true
                            });
                            this.eventHandler(ControlEvents.TouchDragEnter, this, touch);
                            this.inside = true;
                        }
                    }
                    else {
                        this.eventHandler(ControlEvents.TouchDragOutside, this, touch);
                        // console.log("TouchDragOutside")
                        if (this.inside) {
                            this.setState({
                                highlighted: false
                            });
                            this.eventHandler(ControlEvents.TouchDragExit, this, touch);
                            this.inside = false;
                        }
                    }
                }
            }
        }
        else if (state == GestureRecognizerState.Ended) {
            this.canceled = true;
            this.setState({
                highlighted: false
            });
            let fingerID = values.touchIDs[values.touchIDs.length - 1];
            if (typeof fingerID === "number" || typeof fingerID === "string") {
                let touch = values.touches[fingerID];
                if (touch !== undefined && !this.highlightedDelayed) {
                    // console.log(touch);
                    // console.log(this.refs["view"].bounds);
                    if (touch.startX + touch.offsetX > -this.props.moveAllow && touch.startY + touch.offsetY > -this.props.moveAllow &&
                        touch.startX + touch.offsetX < this.refs["view"].bounds.width + this.props.moveAllow &&
                        touch.startY + touch.offsetY < this.refs["view"].bounds.height + this.props.moveAllow) {
                        this.eventHandler(ControlEvents.TouchUpInside, this, touch);
                    }
                    else {
                        this.eventHandler(ControlEvents.TouchUpOutside, this, touch);
                    }
                }
                else if (touch !== undefined && this.highlightedDelayed) {
                    // Light Press (轻触)
                    if (touch.offsetX > -this.props.moveAllow && touch.offsetY > -this.props.moveAllow &&
                        touch.offsetX < this.props.moveAllow &&
                        touch.offsetY < this.props.moveAllow) {
                        this.eventHandler(ControlEvents.TouchUpInside, this, touch);
                    }
                }
                else {
                    this.eventHandler(ControlEvents.TouchCancel, this, touch);
                }
            }
            else {
                this.eventHandler(ControlEvents.TouchCancel, this, undefined);
            }
        }
        else if (state == GestureRecognizerState.Cancelled) {
            this.canceled = true;
            this.setState({
                highlighted: false
            });
            let fingerID = values.touchIDs[values.touchIDs.length - 1];
            if (typeof fingerID === "number" || typeof fingerID === "string") {
                let touch = values.touches[fingerID];
                this.eventHandler(ControlEvents.TouchCancel, this, touch);
            }
        }
    }
}
Control.defaultProps = Object.assign({}, View.defaultProps, {
    userInteractionEnabled: true,
    enabled: true,
    selected: false,
    contentHorizontalAlignment: "center",
    contentVerticalAlignment: "center",
    moveAllow: 44.0,
    delaysContentTouches: false,
    handler: () => { },
});
